###############################################################################
#    Copyright (c) 2016 Salvatore Ventura <salvoventura@gmail.com>
#
#      File: settings.py
#
#    Author: Salvatore Ventura <salvoventura@gmail.com>
#      Date: 07 Dec 2016
#   Purpose: Global repository of common constants and values
#
#  Revision: 1
#   Comment: What's new in revision 1
#
###############################################################################
import logging
API_ROOT = 'https://api.unsplash.com'
LIB_NAME = 'pyunsplash'
LOG_LEVEL = logging.ERROR
