###############################################################################
#
#      File: pyunsplash.py
#
#    Author: Salvatore Ventura <salvoventura@gmail.com>
#      Date: 08 Dec 2016
#   Purpose: simplify import statements
#
#   Comment:
#
###############################################################################

"""An open source Python wrapper for the Unsplash REST API"""

from .pyunsplash import PyUnsplash
# TRAVIS_BUILD_NUMBER
# TRAVIS_COMMIT
# TRAVIS_COMMIT_RANGE
# TRAVIS_TAG
__version__ = '1.0.0rc2'
__author__ = 'Salvatore Ventura <salvoventura@gmail.com>'
__license__ = 'MIT'
